@@ -6,7 +6,7 @@ package WWW::TheEchoNest::TasteProfile;
 use Moose;
 
 {
-    $WWW::TheEchoNest::TasteProfile::VERSION = '1.0';
+    $WWW::TheEchoNest::TasteProfile::VERSION = '1.1';
 }
 
 extends 'WWW::TheEchoNest';
@@ -14,97 +14,97 @@ extends 'WWW::TheEchoNest';
 sub create {
     my ($self,%extra) = @_;
 
-    return $self->send_post_request('catalog/create',\%extra);
+    return $self->send_post_request('tasteprofile/create',\%extra);
 }
 
 sub update {
     my ($self,%extra) = @_;
 
-    return $self->send_post_request('catalog/update',\%extra);
+    return $self->send_post_request('tasteprofile/update',\%extra);
 }
 
 sub keyvalues {
     my ($self,%extra) = @_;
 
-    return $self->request_with_minimum('catalog/keyvalues',\%extra);
+    return $self->request_with_minimum('tasteprofile/keyvalues',\%extra);
 }
 
 sub play {
     my ($self,%extra) = @_;
 
-    return $self->request_with_minimum('catalog/play',\%extra);
+    return $self->request_with_minimum('tasteprofile/play',\%extra);
 }
 
 sub skip {
     my ($self,%extra) = @_;
 
-    return $self->request_with_minimum('catalog/skip',\%extra);
+    return $self->request_with_minimum('tasteprofile/skip',\%extra);
 }
 
 sub favorite {
     my ($self,%extra) = @_;
 
-    return $self->request_with_minimum('catalog/favorite',\%extra);
+    return $self->request_with_minimum('tasteprofile/favorite',\%extra);
 }
 
 sub ban {
     my ($self,%extra) = @_;
 
-    return $self->request_with_minimum('catalog/ban',\%extra);
+    return $self->request_with_minimum('tasteprofile/ban',\%extra);
 }
 
 sub rate {
     my ($self,%extra) = @_;
 
-    return $self->request_with_minimum('catalog/rate',\%extra);
+    return $self->request_with_minimum('tasteprofile/rate',\%extra);
 }
 
 sub status {
     my ($self,%extra) = @_;
 
-    return $self->request_with_minimum('catalog/status',\%extra);
+    return $self->request_with_minimum('tasteprofile/status',\%extra);
 }
 
 sub profile {
     my ($self,%extra) = @_;
 
-    return $self->request_with_minimum('catalog/profile',\%extra);
+    return $self->request_with_minimum('tasteprofile/profile',\%extra);
 }
 
 sub read {
     my ($self,%extra) = @_;
 
-    return $self->request_with_minimum('catalog/read',\%extra);
+    return $self->request_with_minimum('tasteprofile/read',\%extra);
 }
 
 sub feed {
     my ($self,%extra) = @_;
 
-    return $self->request_with_minimum('catalog/feed',\%extra);
+    return $self->request_with_minimum('tasteprofile/feed',\%extra);
 }
 
 sub delete {
     my ($self,%extra) = @_;
 
-    return $self->send_post_request('catalog/delete',\%extra);
+    return $self->send_post_request('tasteprofile/delete',\%extra);
 }
 
 sub list {
     my ($self,%extra) = @_;
 
-    return $self->request_with_minimum('catalog/list',\%extra);
+    return $self->request_with_minimum('tasteprofile/list',\%extra);
 }
 
 sub similar {
     my ($self,%extra) = @_;
 
-    return $self->request_with_minimum('catalog/similar',\%extra);
+    return $self->request_with_minimum('tasteprofile/similar',\%extra);
 }
 
 sub predict {
     my ($self,%extra) = @_;
 
-    return $self->request_with_minimum('catalog/predict',\%extra);
+    return $self->request_with_minimum('tasteprofile/predict',\%extra);
 }
 
 no Moose;
@@ -122,30 +122,30 @@ WWW::TheEchoNest::TasteProfile - Wrapper for The Echo Nest API of music intellig
 
 =head1 VERSION
 
-version 0.4
+version 1.1
 
 =head1 SYNOPSIS
 
 my $api_key = $ENV{EN_API_KEY} || 'YOUR EN API KEY';
 
-my $catalog = WWW::TheEchoNest::TasteProfile->new( api_key => $api_key );
+my $tasteprofile = WWW::TheEchoNest::TasteProfile->new( api_key => $api_key );
 
-# don't do this in the real world! each catalog name has to be unique
+# don't do this in the real world! each taste profile name has to be unique
 # so create something to ensure you can locate them in the future
 
 my $cat_name = "WWWTheEchoNestTest_$$" . rand(1000); 
 
-# create an artist catalog
+# create an artist tasteprofile
 
-$catalog->create( type => 'artist' , name => $cat_name );
+$tasteprofile->create( type => 'artist' , name => $cat_name );
 
-my $catalog_id = $catalog->get( 'id' );
+my $tasteprofile_id = $tasteprofile->get( 'id' );
 
 =head1 DESCRIPTION
 
-Allows for interacting with The Echo Nest Taste Profile (/catalog) calls
+Allows for interacting with The Echo Nest Taste Profile (/tasteprofile) calls
 
-The catalog calls rely on json that is passed in to perform certain actions
+The taste profile calls rely on json that is passed in to perform certain actions
 so you should have a good JSON checker handy.  This module provides a crude
 good or bad method you can use to check the JSON before sending. See the
 synopsis below.
@@ -161,95 +161,95 @@ WWW::TheEchoNest::TasteProfile
 
 =head2 ban
 
-Ban a particular catalog item. This can also be done through the update
+Ban a particular taste profile item. This can also be done through the update
 method, but this method only allows for one item at a time.
 
- $catalog->ban( id => 'CAxxxxxxxxxxxxxxxx',
+ $tasteprofile->ban( id => 'CAxxxxxxxxxxxxxxxx',
                 item => 'theItemName'
                 );
 
 =head2 create
 
- $catalog->create();
+ $tasteprofile->create();
 
 =head2 delete
 
- $catalog->delete();
+ $tasteprofile->delete();
 
 =head2 favorite
 
- $catalog->favorite();
+ $tasteprofile->favorite();
 
 =head2 feed
 
- $catalog->feed();
+ $tasteprofile->feed();
 
 =head2 keyvalues
 
- $catalog->keyvalues();
+ $tasteprofile->keyvalues();
 
 =head2 list
 
- $catalog->list();
+ $tasteprofile->list();
 
 =head2 play
 
- $catalog->play();
+ $tasteprofile->play();
 
 =head2 predict
 
- $catalog->predict();
+ $tasteprofile->predict();
 
 =head2 profile
 
- $catalog->profile( id => 'CAxxxxxxxxxxxxxxxx' );
+ $tasteprofile->profile( id => 'CAxxxxxxxxxxxxxxxx' );
  
- # if catalog exists
+ # if tasteprofile exists
  
- my $tickets = $catalog->get( 'catalog.pending_tickets' );
+ my $tickets = $tasteprofile->get( 'tasteprofile.pending_tickets' );
  
  # the above will return an array ref that contains the list of
  # of pending tickts if any.
  
- my ($total,$resolved) = $catalog->get( 'catalog.total',
-                                        'catalog.resolved'
+ my ($total,$resolved) = $tasteprofile->get( 'tasteprofile.total',
+                                        'tasteprofile.resolved'
                                         );
 
  print "There are $total items in 'CAxxxxxxxxxxxxxxxx' and $resolved of them have been resolved\n";
 
 =head2 rate
 
-Allows you to rate a particular catalog item.
+Allows you to rate a particular taste profile item.
 
- $catalog->rate(
+ $tasteprofile->rate(
                     id => 'CAxxxxxxxxxxxxxxxx',
                     item => 'theItemName' );
  
  # defaults to 5 you can also pass in 0 - 10
  
- $catalog->rate(    'CAxxxxxxxxxxxxxxxx',
+ $tasteprofile->rate(    'CAxxxxxxxxxxxxxxxx',
                     item => 'theItemName',
                     rating => 9
                     );
 
 =head2 read
 
- $catalog->read();
+ $tasteprofile->read();
 
 =head2 similar
 
- $catalog->similar();
+ $tasteprofile->similar();
 
 =head2 skip
 
- $catalog->skip();
+ $tasteprofile->skip();
 
 =head2 status
 
 Get the status of an update that has been sent. You must have a ticket to
 reference. A ticket is a md5 checksum that is returned with the update call.
 
- $catalog->status( ticket => 'abcdeabcdeabcdeabcdeabcdeabcdeab' );
+ $tasteprofile->status( ticket => 'abcdeabcdeabcdeabcdeabcdeabcdeab' );
 
 =head2 update
 
@@ -274,18 +274,18 @@ would like to update.
       }
     ]~;
     
- $catalog->update(  id => 'CAxxxxxxxxxxxxxxxx',
+ $tasteprofile->update(  id => 'CAxxxxxxxxxxxxxxxx',
                     data => $keyvalue_json
                   );
 
-This method can also be used to update the catalog (not the items) with
+This method can also be used to update the taste profile (not the items) with
 key value pairs. The Echo Nest documentation contain more specifics on
 what is allowed.
 
-    my $catalog_kv_json = qq~[
+    my $tasteprofile_kv_json = qq~[
        {
            "action":"update",
-           "catalog_keyvalues": {
+           "tasteprofile_keyvalues": {
                 "type": "user",
                 "gender": "male",
                 "yob": "1959",
@@ -294,11 +294,11 @@ what is allowed.
        }
     ]~;
 
- $catalog->update(  id => 'CAxxxxxxxxxxxxxxxx',
-                    data => $catalog_kv_json
+ $tasteprofile->update(  id => 'CAxxxxxxxxxxxxxxxx',
+                    data => $tasteprofile_kv_json
                   );
 
-Reminder that "catalog_keyvalues" is for the *catalog* not the individual
+Reminder that "tasteprofile_keyvalues" is for the *tasteprofile* not the individual
 items.
 
 =head1 AUTHOR
@@ -307,7 +307,7 @@ Aaron Johnson <aaronjjohnson@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Aaron Johnson.
+This software is copyright (c) 2014 by Aaron Johnson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
